@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,11 +23,13 @@
 
 #include <QByteArray>
 #include <QDateTime>
+#include <QDir>
+#include <QFileInfo>
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonValue>
-#include <QPair>
 #include <QStringBuilder>
+#include <QUrl>
 
 #include "src/datovka_shared/html/html_export.h"
 #include "src/datovka_shared/isds/box_interface.h"
@@ -956,7 +958,9 @@ QString Html::Export::htmlMsgDbLocationInfoApp(const QStringList &dbFiles)
 	}
 	for (const QString &file : dbFiles) {
 		html.append(strongInfoLine(tr("local database file"),
-		    file));
+		    QString("<a href=\"%1\" style=\"color:#0086fb; text-decoration:underline;\">%2</a> ")
+		        .arg(QUrl::fromLocalFile(QFileInfo(file).absoluteFilePath()).toString())
+		        .arg(QDir::toNativeSeparators(file))));
 	}
 	html.append(divEnd);
 	return html;
