@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,9 +21,13 @@
  * the two.
  */
 
+#include <QApplication>
+#include <QPainter>
+
 #include "src/datovka_shared/log/log.h"
 #include "src/delegates/tag_item.h"
 #include "src/delegates/tags_delegate.h"
+#include "src/dimensions/dimensions.h"
 
 TagsDelegate::TagsDelegate(QWidget *parent)
     : QStyledItemDelegate(parent)
@@ -34,8 +38,25 @@ void TagsDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
     const QModelIndex &index) const
 {
 	if (index.data().canConvert<TagItem>()) {
+		const bool checkable = index.flags() & Qt::ItemIsUserCheckable;
+		QStyleOptionViewItem opt = option;
+		if (checkable) {
+			painter->save();
+			initStyleOption(&opt, index);
+			QStyledItemDelegate::paint(painter, opt, index);
+		}
+
 		TagItem tagItem = qvariant_cast<TagItem>(index.data());
+		if (checkable) {
+			int width = QApplication::style()->subElementRect(QStyle::SE_CheckBoxIndicator, &opt).width();
+			painter->translate(width + 6, 0);
+		}
 		tagItem.paint(painter, option);
+
+		if (checkable) {
+			painter->restore();
+		}
+
 	} else if (index.data().canConvert<TagItemList>()) {
 		TagItemList tagList = qvariant_cast<TagItemList>(index.data());
 		tagList.paint(painter, option);
@@ -56,4 +77,4 @@ QSize TagsDelegate::TagsDelegate::sizeHint(const QStyleOptionViewItem &option,
 	} else {
 		return QStyledItemDelegate::sizeHint(option, index);
 	}
-}
+}
\ No newline at end of file
