@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,9 +50,9 @@ class AcntIdDb; /* Forward declaration. */
 class MessageDbSet; /* Forward declaration. */
 class Prefs; /* Forward declaration. */
 class QComboBox; /* Forward declaration. */
-class QLabel; /* Forward declaration. */
 class QLineEdit; /* Forward declaration. */
 class QProgressBar; /* Forward declaration. */
+class QUrl; /* Forward declaration. */
 
 namespace Ui {
 	class MainWindow;
@@ -499,15 +499,27 @@ private slots:
 	void closeMessageSearchDlg(int result);
 
 	/*!
-	 * @brief Show tag manager dialogue window.
+	 * @brief Show available tag manager dialogue window.
 	 */
-	void viewTagDlg(void);
+	void viewAvailableTagsDlg(void);
 
 	/*!
 	 * @brief Show convert and import from mobile app dialogue window.
 	 */
 	void viewConvertImportFromMobileAppDlg(void);
 
+	/*!
+	 * @brief Quit application and continue with database repair.
+	 */
+	void repairDatabaseFiles(void);
+
+	/*!
+	 * @brief Quit application and continue with database repair.
+	 *
+	 * @param[in] link File URL.
+	 */
+	void repairDatabaseFile(const QUrl &link);
+
 	/*!
 	 * @brief Store top tool bar visibility into preferences.
 	 */
@@ -663,11 +675,6 @@ private slots:
 	 */
 	void messageItemsSelectedMarkSettled(void);
 
-	/*!
-	 * @brief Assign tags to selected messages.
-	 */
-	void messageItemsSelectedAssignTags(void);
-
 /* Filter-field-related actions. */
 	/*!
 	 * @brief Show message list filter.
@@ -767,6 +774,21 @@ private slots:
 	 */
 	void viewAttachmentToolBarContextMenu(const QPoint &point);
 
+	/*!
+	 * @brief Show classic tag assignment dialogue or pop-up.
+	 */
+	void viewTagAssignmentInterface(void);
+
+	/*!
+	 * @brief Show classic tag assignment dialogue.
+	 */
+	void viewTagAssignmentDialogue(void);
+
+	/*!
+	 * @brief Show tag assignment pop-up.
+	 */
+	void viewTagAssignmentPopup(void);
+
 /* Mouse on view clicks. */
 	/*!
 	 * @brief Generates a context menu depending on the item and selection
@@ -776,6 +798,19 @@ private slots:
 	 */
 	void viewAccountListContextMenu(const QPoint &point);
 
+	/*!
+	 * @brief Create custom context menu when clicking on anchors in the
+	 *     account text info.
+	 */
+	void viewAccountTextInfoContextMenu(const QPoint &point);
+
+	/*!
+	 * @brief Open an URL when clicked on a link in the account text info.
+	 *
+	 * @param[in] link File URL.
+	 */
+	void viewAccountTextInfoAnchorClicked(const QUrl &link);
+
 	/*!
 	 * @brief Generates a context menu depending on the item and selection
 	 *     it was invoked on.
@@ -937,12 +972,29 @@ public:
 	 */
 	bool connectToIsds(const AcntId &acntId, bool shadow = false);
 
+public slots:
+	/*!
+	 * @brief Changes the application theme.
+	 *
+	 * @param[in] index Theme index.
+	 */
+	void changeTheme(int index);
+
 private slots:
 	/*!
 	 * @brief Refresh account list.
 	 */
 	void refreshAccountList(const AcntId &acntId);
 
+	/*!
+	 * @brief Display a status bar notification that database file cannot
+	 *     be opened.
+	 *
+	 * @param[in] acntId Account identifier.
+	 * @param[in] fileName Database file name.
+	 */
+	void watchOpeningFailed(const AcntId &acntId, const QString &fileName);
+
 	/*!
 	 * @brief Processes messages from single instance emitter.
 	 */
@@ -1422,7 +1474,7 @@ private:
 
 	QDialog *m_messageSearchDlg; /*!< Non-null if message search dialogue is active. */
 	QDialog *m_logDlg; /*!< Non-null if log dialogue is active. */
-	QDialog *m_askCloseDlg; /*!< Non-null if ask cancel stask dialogue is active. */
+	QDialog *m_askCloseDlg; /*!< Non-null if ask cancel task dialogue is active. */
 
 	QVector<int> m_colWidth; /*!< Message list column widths. */
 	int m_sortCol; /*!< Column with enabled sorting. */
@@ -1444,8 +1496,8 @@ private:
 	QAction *mui_lastUnconfigurableAttachmentToolBarElement; /*!< Last attachment list tool bar element that cannot be configured. */
 	QToolBar *mui_attachmentToolBar; /*!< Attachment list tool bar. */
 	QStatusBar *mui_statusBar; /*!< Status bar. */
-	QLabel *mui_statusDbMode; /*!< Database status label. */
-	QLabel *mui_statusTagMode; /*!< Tag storage status label. */
+	QWidget *mui_dbStatusMode; /*!< Database status label/widget. */
+	QWidget *mui_statusLabelTags; /*!< Tag status label/widget. */
 	QWidget *mui_statusAccounts; /*!< Account status label/widget. */
 	QProgressBar *mui_statusProgressBar; /*!< Progress bar. */
 	QMenu mui_dockMenu; /*!< Dock menu for macOS. */
