@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -148,8 +148,6 @@ DlgSendMessage::DlgSendMessage(const QList<AcntIdDb> &acntIdDbList,
 	/* Generate random directory where files can be created. */
 	m_tmpDirPath = createTemporarySubdir(TMP_DIR_NAME);
 
-	setIcons();
-
 	/* Set default line height for table views/widgets. */
 	m_ui->recipTableView->setNarrowedLineHeight();
 	m_ui->recipTableView->horizontalHeader()->setDefaultAlignment(Qt::AlignVCenter | Qt::AlignLeft);
@@ -808,7 +806,7 @@ void DlgSendMessage::watchUploadProgress(const AcntId &acntId,
 		/* Update attachment progress. */
 		m_attachProgressProxyModel.setProgress(
 		    row, ATTACH_PROGRESS_COL,
-		    0, uploadTotal, uploadCurrent);
+		    0, uploadTotal, uploadCurrent, QString());
 		return;
 	}
 
@@ -817,7 +815,7 @@ void DlgSendMessage::watchUploadProgress(const AcntId &acntId,
 		/* Update message progress. */
 		m_recipProgressProxyModel.setProgress(
 		    row, RECIP_PROGRESS_COL,
-		    0, uploadTotal, uploadCurrent);
+		    0, uploadTotal, uploadCurrent, QString());
 		return;
 	}
 }
@@ -1085,7 +1083,8 @@ void DlgSendMessage::initContent(enum Action action, const QList<MsgId> &msgIds)
 	    SIGNAL(sendMessageFinished(AcntId, QString, int, QString,
 	        QString, QString, bool, bool, qint64, int, QString)), this,
 	    SLOT(collectSendMessageStatus(AcntId, QString, int, QString,
-	        QString, QString, bool, bool, qint64, int, QString )));
+	        QString, QString, bool, bool, qint64, int, QString )),
+	    Qt::QueuedConnection); /* Qt::QueuedConnection because it must be executed in receiver's thread. */
 
 	connect(GlobInstcs::msgProcEmitterPtr, SIGNAL(uploadProgress(AcntId, QString, qint64, qint64)),
 	    this, SLOT(watchUploadProgress(AcntId, QString, qint64, qint64)),
@@ -2292,33 +2291,6 @@ finish:
 	this->close();
 }
 
-void DlgSendMessage::setIcons(void)
-{
-	m_ui->addRecipButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_RECIPIENT_ADD));
-
-	m_ui->findRecipButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_RECIPIENT_FIND));
-
-	m_ui->removeRecipButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_RECIPIENT_DELETE));
-
-	m_ui->enterBoxIdButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_APP_PENCIL));
-
-	m_ui->addAttachButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_ATTACHMENT_ADD));
-
-	m_ui->openAttachButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_ATTACHMENT_OPEN));
-
-	m_ui->removeAttachButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_ATTACHMENT_DELETE));
-
-	m_ui->addTextButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_MESSAGE_ADD_DOCUMENT));
-}
-
 void DlgSendMessage::setPDZInfos(const QList<Isds::PDZInfoRec> &pdzInfos)
 {
 	m_pdzInfos = pdzInfos;
