@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -837,8 +837,6 @@ void DlgTagSettings::watchServerTagsDeleted(const Json::Int64StringList &ids)
 
 void DlgTagSettings::initDialogue(const TagContainerSettings &tagContSet)
 {
-	setIcons();
-
 	/* Server connection tab. */
 	m_ui->tagSrvrPortLineEdit->setValidator(
 	    new (::std::nothrow) QIntValidator(0, 65535, m_ui->tagSrvrPortLineEdit));
@@ -963,15 +961,3 @@ void DlgTagSettings::initDialogue(const TagContainerSettings &tagContSet)
 
 	m_ui->updateServerTagButton->setEnabled(false);
 }
-
-void DlgTagSettings::setIcons(void)
-{
-	m_ui->updateLocalTagButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_APP_PENCIL));
-
-	m_ui->toServerButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_APP_ARROW_RIGHT));
-
-	m_ui->updateServerTagButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_APP_PENCIL));
-}
