@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,7 +36,6 @@
 
 namespace Json {
 	class TagMsgId; /* Forward declaration. */
-	class TagMsgIdList; /* Forward declaration. */
 }
 class TagContainer; /* Forward declaration. */
 class TagItemList; /* Forward declaration. */
@@ -83,13 +82,12 @@ public:
 	/*!
 	 * @brief Edit all tags.
 	 *
-	 * @param[in] acntId Account identifier.
 	 * @param[in] tagCont Pointer to tag container.
 	 * @param[in] parent Parent widget.
 	 * @return Return code.
 	 */
 	static
-	enum ReturnCode editAvailable(const AcntId &acntId, TagContainer *tagCont,
+	enum ReturnCode editAvailable(TagContainer *tagCont,
 	    QWidget *parent = Q_NULLPTR);
 
 	/*!
@@ -194,18 +192,17 @@ private slots:
 
 private:
 	/*!
-	 * @brief Fill all tag entries into list views from database.
-	 *
-	 * @param[in] msgIdList List of message IDs.
+	 * @brief Fill all assignment-related data from tag container.
 	 */
-	void fillTagsToListViews(const Json::TagMsgIdList &msgIdList);
+	void loadAssignments(void);
 
 	/*!
 	 * @brief Initialises the dialogue.
 	 *
-	 * @param[in] msgIdList List of message IDs.
+	 * @paran[in] enableTagAssignment Whether to enable tag to message
+	 *                                assignment functionality.
 	 */
-	void initDlg(const QList<qint64> &msgIdList);
+	void initDlg(bool enableTagAssignment);
 
 	/*!
 	 * @brief Load model content.
