@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -299,8 +299,6 @@ void DlgViewZfo::setUpDialogue(void)
 	}
 
 	/* Signature details. */
-	m_ui->signatureDetailsButton->setIcon(
-	    IconContainer::construcIcon(IconContainer::ICON_MESSAGE_SIGNATURE));
 	connect(m_ui->signatureDetailsButton, SIGNAL(clicked()), this,
 	    SLOT(showSignatureDetailsDlg()));
 }
