@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -184,20 +184,16 @@ void downloadCRL(void)
 	}
 }
 
-void loadLocalisation(const Prefs &prefs)
+/*!
+ * @brief Loads application localisation depending on \a language.
+ *
+ * @param[in] language Language string.
+ */
+static
+void loadLocalisation(const QString &language)
 {
 	static QTranslator qtTranslator, appTranslator;
 
-	QString language;
-	{
-		QString val;
-		if (prefs.strVal("translation.language", val)) {
-			if (!val.isEmpty()) {
-				language = macroStdMove(val);
-			}
-		}
-	}
-
 	/* Check for application localisation location. */
 	QString localisationDir;
 	QString localisationFile;
@@ -246,6 +242,26 @@ void loadLocalisation(const Prefs &prefs)
 	QCoreApplication::installTranslator(&qtTranslator);
 }
 
+void loadLocalisationSystem(void)
+{
+	loadLocalisation(Localisation::langSystem);
+}
+
+void loadLocalisationPrefs(const Prefs &prefs)
+{
+	QString language;
+	{
+		QString val;
+		if (prefs.strVal("translation.language", val)) {
+			if (!val.isEmpty()) {
+				language = macroStdMove(val);
+			}
+		}
+	}
+
+	loadLocalisation(language);
+}
+
 void logAppVersion(void)
 {
 	/* Crude architecture bit width check. */
@@ -489,9 +505,12 @@ void createBackupOfOldFormatData(const INIPreferences &iniPrefs)
 }
 #endif /* defined(ENABLE_TAGS) */
 
-int allocGlobContainers(const Prefs &prefs, const INIPreferences &iniPrefs)
+enum InitialisationError allocGlobContainers(const Prefs &prefs,
+    const INIPreferences &iniPrefs, QString *problemPathPtr)
 {
 	SQLiteDb::OpenFlags flags = SQLiteDb::NO_OPTIONS;
+	QString problemPath;
+	enum InitialisationError retCode = SUCCESS;
 
 	/*
 	 * These objects cannot be globally accessible static objects.
@@ -504,12 +523,14 @@ int allocGlobContainers(const Prefs &prefs, const INIPreferences &iniPrefs)
 	GlobInstcs::isdsSessionsPtr = new (::std::nothrow) IsdsSessions;
 	if (Q_UNLIKELY(Q_NULLPTR == GlobInstcs::isdsSessionsPtr)) {
 		logErrorNL("%s", "Cannot allocate session container.");
+		retCode = ERR_ALLOC_RESOURCES;
 		goto fail;
 	}
 
 	GlobInstcs::accntDbPtr = new (::std::nothrow) AccountDb("accountDb", false);
 	if (Q_UNLIKELY(Q_NULLPTR == GlobInstcs::accntDbPtr)) {
 		logErrorNL("%s", "Cannot allocate account db.");
+		retCode = ERR_ALLOC_RESOURCES;
 		goto fail;
 	}
 	/* Open accounts database. */
@@ -519,6 +540,8 @@ int allocGlobContainers(const Prefs &prefs, const INIPreferences &iniPrefs)
 	if (Q_UNLIKELY(!GlobInstcs::accntDbPtr->openDb(iniPrefs.acntDbPath(), flags))) {
 		logErrorNL("Error opening account db '%s'.",
 		    iniPrefs.acntDbPath().toUtf8().constData());
+		problemPath = iniPrefs.acntDbPath();
+		retCode = ERR_OPEN_FILES;
 		goto fail;
 	}
 
@@ -527,6 +550,7 @@ int allocGlobContainers(const Prefs &prefs, const INIPreferences &iniPrefs)
 	    PrefsSpecific::messageDbOnDisk(prefs), "GLOBALDBS");
 	if (Q_UNLIKELY(Q_NULLPTR == GlobInstcs::msgDbsPtr)) {
 		logErrorNL("%s", "Cannot allocate message db container.");
+		retCode = ERR_ALLOC_RESOURCES;
 		goto fail;
 	}
 
@@ -534,16 +558,19 @@ int allocGlobContainers(const Prefs &prefs, const INIPreferences &iniPrefs)
 	GlobInstcs::tagContSetPtr = new (::std::nothrow) TagContainerSettings();
 	if (Q_UNLIKELY(Q_NULLPTR == GlobInstcs::tagContSetPtr)) {
 		logErrorNL("%s", "Cannot allocate tag container settings.");
+		retCode = ERR_ALLOC_RESOURCES;
 		goto fail;
 	}
 	GlobInstcs::tagContPtr = new (::std::nothrow) TagContainer(TagContainer::BACK_DB);
 	if (Q_UNLIKELY(Q_NULLPTR == GlobInstcs::tagContPtr)) {
 		logErrorNL("%s", "Cannot allocate tag container.");
+		retCode = ERR_ALLOC_RESOURCES;
 		goto fail;
 	}
 	/* Check tag database backend presence. */
 	if (Q_UNLIKELY(Q_NULLPTR == GlobInstcs::tagContPtr->backendDb())) {
 		logErrorNL("%s", "Cannot allocate tag db.");
+		retCode = ERR_ALLOC_RESOURCES;
 		goto fail;
 	}
 	/* Open tags database. */
@@ -551,11 +578,14 @@ int allocGlobContainers(const Prefs &prefs, const INIPreferences &iniPrefs)
 	if (Q_UNLIKELY(!GlobInstcs::tagContPtr->backendDb()->openDb(iniPrefs.tagDbPath(), flags))) {
 		logErrorNL("Error opening tag db '%s'.",
 		    iniPrefs.tagDbPath().toUtf8().constData());
+		problemPath = iniPrefs.tagDbPath();
+		retCode = ERR_OPEN_FILES;
 		goto fail;
 	}
 	/* Check tag client backend presence. */
 	if (Q_UNLIKELY(Q_NULLPTR == GlobInstcs::tagContPtr->backendClient())) {
 		logErrorNL("%s", "Cannot allocate tag client.");
+		retCode = ERR_ALLOC_RESOURCES;
 		goto fail;
 	}
 #endif /* defined(ENABLE_TAGS) */
@@ -564,6 +594,7 @@ int allocGlobContainers(const Prefs &prefs, const INIPreferences &iniPrefs)
 	    RecordsManagementDb("recordsManagementDb", false);
 	if (Q_UNLIKELY(Q_NULLPTR == GlobInstcs::recMgmtDbPtr)) {
 		logErrorNL("%s", "Cannot allocate records management db.");
+		retCode = ERR_ALLOC_RESOURCES;
 		goto fail;
 	}
 	/* Open records management database. */
@@ -571,6 +602,8 @@ int allocGlobContainers(const Prefs &prefs, const INIPreferences &iniPrefs)
 	if (Q_UNLIKELY(!GlobInstcs::recMgmtDbPtr->openDb(iniPrefs.recMgmtDbPath(), flags))) {
 		logErrorNL("Error opening records management db '%s'.",
 		    iniPrefs.recMgmtDbPath().toUtf8().constData());
+		problemPath = iniPrefs.recMgmtDbPath();
+		retCode = ERR_OPEN_FILES;
 		goto fail;
 	}
 
@@ -578,6 +611,7 @@ int allocGlobContainers(const Prefs &prefs, const INIPreferences &iniPrefs)
 	    AcntContainer::CT_REGULAR);
 	if (Q_UNLIKELY(Q_NULLPTR == GlobInstcs::acntMapPtr)) {
 		logErrorNL("%s", "Cannot allocate account container.");
+		retCode = ERR_ALLOC_RESOURCES;
 		goto fail;
 	}
 
@@ -585,14 +619,18 @@ int allocGlobContainers(const Prefs &prefs, const INIPreferences &iniPrefs)
 	    AcntContainer::CT_SHADOW);
 	if (Q_UNLIKELY(Q_NULLPTR == GlobInstcs::shadowAcntsPtr)) {
 		logErrorNL("%s", "Cannot allocate shadow account container.");
+		retCode = ERR_ALLOC_RESOURCES;
 		goto fail;
 	}
 
-	return 0;
+	return SUCCESS;
 
 fail:
 	deallocGlobContainers();
-	return -1;
+	if (Q_NULLPTR != problemPathPtr) {
+		*problemPathPtr = macroStdMove(problemPath);
+	}
+	return retCode;
 }
 
 void deallocGlobContainers(void)
