@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,8 +29,9 @@ class Prefs; /* Forward declaration. */
  * @brief Load application UI theme.
  *
  * @param[in] index Value as defined by enum PrefsSpecific::AppUiTheme.
+ * @param[in] fontScalePercent Font scale in percent.
  */
-void loadAppUiThemeFromIndex(const int index);
+void loadAppUiThemeFromValues(const int index, const int fontScalePercent);
 
 /*!
  * @brief Load application UI theme.
