@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -219,7 +219,7 @@ fail:
 
 QString nonconflictingFileName(QString filePath)
 {
-	if (filePath.isEmpty()) {
+	if (Q_UNLIKELY(filePath.isEmpty())) {
 		return QString();
 	}
 
@@ -247,21 +247,21 @@ QString nonconflictingFileName(QString filePath)
 enum WriteFileState writeFile(const QString &filePath, const QByteArray &data,
     bool deleteOnError)
 {
-	if (filePath.isEmpty()) {
+	if (Q_UNLIKELY(filePath.isEmpty())) {
 		Q_ASSERT(0);
 		return WF_ERROR;
 	}
 
 	QFile fout(filePath);
-	if (!fout.open(QIODevice::WriteOnly)) {
+	if (Q_UNLIKELY(!fout.open(QIODevice::WriteOnly))) {
 		return WF_CANNOT_CREATE;
 	}
 
-	int written = fout.write(data);
+	qint64 written = fout.write(data);
 	bool flushed = fout.flush();
 	fout.close();
 
-	if ((written != data.size()) || !flushed) {
+	if (Q_UNLIKELY((written != data.size()) || !flushed)) {
 		if (deleteOnError) {
 			QFile::remove(filePath);
 		}
@@ -396,7 +396,7 @@ QString createTemporarySubdir(const QString &nameTemplate)
 QString writeTemporaryFile(const QString &fileName, const QByteArray &data,
     bool deleteOnError)
 {
-	if (fileName.isEmpty()) {
+	if (Q_UNLIKELY(fileName.isEmpty())) {
 		Q_ASSERT(0);
 		return QString();
 	}
@@ -406,7 +406,7 @@ QString writeTemporaryFile(const QString &fileName, const QByteArray &data,
 
 	/* StandardLocation::writableLocation(QStandardPaths::TempLocation) ? */
 	QTemporaryFile fout(tempDirPath(true, true) + QDir::separator() + nameCopy);
-	if (!fout.open()) {
+	if (Q_UNLIKELY(!fout.open())) {
 		return QString();
 	}
 	fout.setAutoRemove(false);
@@ -414,11 +414,11 @@ QString writeTemporaryFile(const QString &fileName, const QByteArray &data,
 	/* Get whole path. */
 	QString fullName = fout.fileName();
 
-	int written = fout.write(data);
+	qint64 written = fout.write(data);
 	bool flushed = fout.flush();
 	fout.close();
 
-	if ((written != data.size()) || !flushed) {
+	if (Q_UNLIKELY((written != data.size()) || !flushed)) {
 		if (deleteOnError) {
 			QFile::remove(fullName);
 		}
