@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -344,8 +344,8 @@ bool p12CertificateToPem(const QString &p12Path, const QString &certPwd,
 
 	void *pem = NULL;
 	size_t pem_size;
-	if (0 != p12_to_pem((void *) p12Data.constData(), p12Data.size(),
-	        certPwd.toUtf8().constData(), &pem, &pem_size)) {
+	if (Q_UNLIKELY(0 != p12_to_pem((void *)p12Data.constData(), p12Data.size(),
+	        certPwd.toUtf8().constData(), &pem, &pem_size))) {
 		return false;
 	}
 
@@ -353,19 +353,19 @@ bool p12CertificateToPem(const QString &p12Path, const QString &certPwd,
 	    userName + "_" + QFileInfo(p12Path).fileName() + "_.pem");
 
 	QFile pemFile(pemTmpPath);
-	if (!pemFile.open(QIODevice::WriteOnly)) {
+	if (Q_UNLIKELY(!pemFile.open(QIODevice::WriteOnly))) {
 		::std::free(pem); pem = NULL;
 		return false;
 	}
 
-	if ((long) pem_size != pemFile.write((char *) pem, pem_size)) {
+	if (Q_UNLIKELY((qint64)pem_size != pemFile.write((char *)pem, pem_size))) {
 		::std::free(pem); pem = NULL;
 		return false;
 	}
 
 	::std::free(pem); pem = NULL;
 
-	if (!pemFile.flush()) {
+	if (Q_UNLIKELY(!pemFile.flush())) {
 		return false;
 	}
 
