@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -55,6 +55,8 @@ MessageDbSet::~MessageDbSet(void)
 		MessageDb *db = i.value();
 		db->disconnect(SIGNAL(opened(QString)),
 		    this, SLOT(watchOpened(QString)));
+		db->disconnect(SIGNAL(openingFailed(QString)),
+		    this, SLOT(watchOpeningFailed(QString)));
 		db->disconnect(SIGNAL(changedLocallyRead(QList<MsgId>, bool)),
 		    this, SLOT(watchChangedLocallyRead(QList<MsgId>, bool)));
 		db->disconnect(SIGNAL(changedProcessState(QList<MsgId>, enum MessageDb::MessageProcessState)),
@@ -1210,28 +1212,33 @@ void MessageDbSet::watchOpened(const QString &fileName)
 {
 	Q_UNUSED(fileName);
 
-	emit opened(m_primaryKey, m_testing);
+	Q_EMIT opened(m_primaryKey, m_testing);
+}
+
+void MessageDbSet::watchOpeningFailed(const QString &fileName)
+{
+	Q_EMIT openingFailed(m_primaryKey, m_testing, fileName);
 }
 
 void MessageDbSet::watchChangedLocallyRead(const QList<MsgId> &msgIds, bool read)
 {
-	emit changedLocallyRead(m_primaryKey, m_testing, msgIds, read);
+	Q_EMIT changedLocallyRead(m_primaryKey, m_testing, msgIds, read);
 }
 
 void MessageDbSet::watchChangedProcessState(const QList<MsgId> &msgIds,
     enum MessageDb::MessageProcessState state)
 {
-	emit changedProcessState(m_primaryKey, m_testing, msgIds, state);
+	Q_EMIT changedProcessState(m_primaryKey, m_testing, msgIds, state);
 }
 
 void MessageDbSet::watchMessageInserted(const MsgId &msgId, int direction)
 {
-	emit messageInserted(m_primaryKey, m_testing, msgId, direction);
+	Q_EMIT messageInserted(m_primaryKey, m_testing, msgId, direction);
 }
 
 void MessageDbSet::watchMessageDataDeleted(const MsgId &msgId)
 {
-	emit messageDataDeleted(m_primaryKey, m_testing, msgId);
+	Q_EMIT messageDataDeleted(m_primaryKey, m_testing, msgId);
 }
 
 MessageDb *MessageDbSet::_accessMessageDb(const QString &secondaryKey,
@@ -1318,6 +1325,8 @@ MessageDb *MessageDbSet::_accessMessageDb(const QString &secondaryKey,
 
 	connect(db, SIGNAL(opened(QString)),
 	    this, SLOT(watchOpened(QString)));
+	connect(db, SIGNAL(openingFailed(QString)),
+	    this, SLOT(watchOpeningFailed(QString)));
 	connect(db, SIGNAL(changedLocallyRead(QList<MsgId>, bool)),
 	    this, SLOT(watchChangedLocallyRead(QList<MsgId>, bool)));
 	connect(db, SIGNAL(changedProcessState(QList<MsgId>, enum MessageDb::MessageProcessState)),
@@ -1328,7 +1337,7 @@ MessageDb *MessageDbSet::_accessMessageDb(const QString &secondaryKey,
 	    this, SLOT(watchMessageDataDeleted(MsgId)));
 
 	this->insert(secondaryKey, db);
-	emit madeAvailable(m_primaryKey, m_testing);
+	Q_EMIT madeAvailable(m_primaryKey, m_testing);
 	return db;
 }
 
