@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -394,7 +394,7 @@ public:
 	bool isValidDbFileName(const QString &fileName, QString &dbUserName,
 	    QString &dbYear, bool &dbTestingFlag, QString &errMsg);
 
-signals:
+Q_SIGNALS:
 	/*!
 	 * @brief Emitted when a database file has been added into the container.
 	 *
@@ -413,6 +413,16 @@ signals:
 	 */
 	void opened(const QString &primaryKey, bool testing);
 
+	/*!
+	 * @brief Emitted when the attempt to open a database file fails.
+	 *
+	 * @param[in] primaryKey Primary key, usually the username.
+	 * @param[in] testing Whether the database is related to a testing account.
+	 * @param[in] fileName Database file name.
+	 */
+	void openingFailed(const QString &primaryKey, bool testing,
+	    const QString &fileName);
+
 	/*!
 	 * @brief Emitted when the locally read flag changes.
 	 *
@@ -457,7 +467,7 @@ signals:
 	void messageDataDeleted(const QString &primaryKey, bool testing,
 	    const MsgId &msgId);
 
-private slots:
+private Q_SLOTS:
 	/*!
 	 * @brief This slot must be connected to every database created inside
 	 *     this container.
@@ -466,6 +476,14 @@ private slots:
 	 */
 	void watchOpened(const QString &fileName);
 
+	/*!
+	 * @brief This slot must be connected to every database created inside
+	 *     this container.
+	 *
+	 * @param[in] fileName Database file name.
+	 */
+	void watchOpeningFailed(const QString &fileName);
+
 	/*!
 	 * @brief This slot must be connected to every database created inside
 	 *     this container.
