@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,8 +30,8 @@
 #include <QNetworkReply>
 #include <QRegularExpression>
 
-#include "src/about.h"
 #include "src/common.h"
+#include "src/datovka_shared/app_version_info.h"
 #include "src/datovka_shared/compat_qt/misc.h"
 #include "src/datovka_shared/log/log.h"
 #include "src/io/filesystem.h"
@@ -247,7 +247,7 @@ QString UpdateChecker::newestVersion(void) const
 bool UpdateChecker::newerVersionAvailable(void) const
 {
 	return (!m_newestVersion.isEmpty()) &&
-	    (1 == compareVersionStrings(m_newestVersion,
+	    (1 == AppVersionInfo::compareVersionStrings(m_newestVersion,
 	         QCoreApplication::applicationVersion()));
 }
 
