@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDateTime>
+#include <QMessageBox>
 #include <QSettings>
 #include <QSplashScreen>
 #include <QStyleFactory>
@@ -44,6 +45,7 @@
 #include "src/datovka_shared/log/memory_log.h"
 #include "src/datovka_shared/settings/pin.h"
 #include "src/datovka_shared/worker/pool.h"
+#include "src/db_repair/gui/mw_db_repair.h"
 #include "src/global.h"
 #include "src/gui/datovka.h"
 #include "src/gui/dlg_pin_input.h"
@@ -221,7 +223,50 @@ int main(int argc, char *argv[])
 	logInfo("Starting at %lld.%03lld .\n", start / 1000, start % 1000);
 
 	/* Create configuration file if file is missing. */
-	GlobInstcs::iniPrefsPtr->ensureConfPresence();
+	{
+		QString problemPath;
+		const enum INIPreferences::ConfPresence presenceCode =
+		    GlobInstcs::iniPrefsPtr->ensureConfPresence(&problemPath);
+		if (Q_UNLIKELY((runMode == RM_GUI)
+		        && (presenceCode != INIPreferences::ACCESSIBLE))) {
+			loadLocalisationSystem();
+			QString errorMessage =
+			    INIPreferences::confPresenceErrorMessage(
+			        presenceCode, problemPath);
+			errorMessage += "\n\n";
+			errorMessage +=
+			    QObject::tr("Please check that you own the permissions to read and write the entire content of the directory '%1'.")
+			        .arg(GlobInstcs::iniPrefsPtr->confDir());
+			QMessageBox::critical(Q_NULLPTR,
+			    QObject::tr("Cannot Access Configuration"),
+			    errorMessage);
+			return EXIT_FAILURE;
+		}
+	}
+	/*
+	 * Check whether there are permissions to modify content of
+	 * configuration directory.
+	 */
+	{
+		QStringList problemPaths;
+		const enum INIPreferences::ConfPresence presenceCode =
+		    GlobInstcs::iniPrefsPtr->checkConfiguration(problemPaths);
+		if (Q_UNLIKELY((runMode == RM_GUI)
+		        && (presenceCode != INIPreferences::ACCESSIBLE))) {
+			loadLocalisationSystem();
+			QString errorMessage =
+			    INIPreferences::confPresenceErrorMessage2(
+			        presenceCode, problemPaths);
+			errorMessage += "\n\n";
+			errorMessage +=
+			    QObject::tr("Please check that you own the permissions to read and write the entire content of the directory '%1'.")
+			        .arg(GlobInstcs::iniPrefsPtr->confDir());
+			QMessageBox::critical(Q_NULLPTR,
+			    QObject::tr("Cannot Access Configuration"),
+			    errorMessage);
+			return EXIT_FAILURE;
+		}
+	}
 
 	logAppVersion();
 	logTimeZone();
@@ -277,8 +322,31 @@ int main(int argc, char *argv[])
 		    true);
 	}
 
+	if (!SQLiteDb::dbDriverSupport()) {
+		logError("Cannot load database driver '%s'.\n",
+		    SQLiteDb::dbDriverType.toUtf8().constData());
+		loadLocalisationSystem();
+		QMessageBox::critical(Q_NULLPTR,
+		    QObject::tr("Missing SQLite Database Driver"),
+		    QObject::tr("Missing SQLite database driver module for the Qt framework."));
+		return EXIT_FAILURE;
+	}
+
 	/* Initialise database-based preferences. */
 	if (Q_UNLIKELY(0 != allocGlobPrefs(*GlobInstcs::iniPrefsPtr))) {
+		loadLocalisationSystem();
+		QString errorMessage =
+		    QObject::tr("Cannot open preferences database file '%1'.")
+		        .arg(GlobInstcs::iniPrefsPtr->prefsDbPath());
+		errorMessage += "\n\n";
+		errorMessage +=
+		    QObject::tr("You may move, rename or delete this file. It doesn't contain any message data.");
+		errorMessage += "\n\n";
+		errorMessage +=
+		    QObject::tr("If you remove the file then all application settings will be reset to default values.");
+		QMessageBox::critical(Q_NULLPTR,
+		    QObject::tr("Cannot Access Preferences"),
+		    errorMessage);
 		return EXIT_FAILURE;
 	}
 
@@ -286,10 +354,26 @@ int main(int argc, char *argv[])
 	PrefsDefaults::setDefaults(*GlobInstcs::prefsPtr);
 	/* Load preferences from database. */
 	if (Q_UNLIKELY(0 != loadPreferencesDatabase())) {
+		loadLocalisationSystem();
+		QString errorMessage =
+		    QObject::tr("Cannot apply content from preferences database file '%1'.")
+		        .arg(GlobInstcs::iniPrefsPtr->prefsDbPath());
+		errorMessage += "\n\n";
+		errorMessage +=
+		    QObject::tr("You may try moving, renaming or deleting this file. It doesn't contain any message data.");
+		errorMessage += "\n\n";
+		errorMessage +=
+		    QObject::tr("If you remove the file then all application settings will be reset to default values.");
+		QMessageBox::critical(Q_NULLPTR,
+		    QObject::tr("Cannot Apply Preferences"),
+		    errorMessage);
 		return EXIT_FAILURE;
 	}
 
-	/* Load and set application UI theme from preferences. */
+	/*
+	 * Load and set application UI theme from preferences.
+	 * Dath theme is detected here.
+	 */
 	loadAppUiTheme(*GlobInstcs::prefsPtr);
 
 	/* Convert INI preferences into database and remove them from INI file. */
@@ -318,13 +402,6 @@ int main(int argc, char *argv[])
 	/* Start downloading the CRL files. */
 	downloadCRL();
 
-	if (!SQLiteDb::dbDriverSupport()) {
-		logError("Cannot load database driver '%s'.\n",
-		    SQLiteDb::dbDriverType.toUtf8().constData());
-		/* TODO -- throw a dialog notifying the user. */
-		return EXIT_FAILURE;
-	}
-
 #if defined(Q_OS_OSX)
 	/* Set style. */
 	{
@@ -344,7 +421,7 @@ int main(int argc, char *argv[])
 	logDebugLv0NL("App path: '%s'.",
 	    app.applicationDirPath().toUtf8().constData());
 
-	loadLocalisation(*GlobInstcs::prefsPtr);
+	loadLocalisationPrefs(*GlobInstcs::prefsPtr);
 
 	/* Ask for PIN. */
 	{
@@ -401,9 +478,37 @@ int main(int argc, char *argv[])
 	createBackupOfOldFormatData(*GlobInstcs::iniPrefsPtr);
 
 	/* Initialise database-based containers. */
-	if (Q_UNLIKELY(0 != allocGlobContainers(*GlobInstcs::prefsPtr,
-	        *GlobInstcs::iniPrefsPtr))) {
-		return EXIT_FAILURE;
+	{
+		QString problemPath;
+		const enum InitialisationError ret = allocGlobContainers(
+		    *GlobInstcs::prefsPtr, *GlobInstcs::iniPrefsPtr,
+		    &problemPath);
+
+		if (Q_UNLIKELY(SUCCESS != ret)) {
+			/* Localisation already loaded. */
+			QString errorMessage;
+			switch (ret) {
+			case ERR_ALLOC_RESOURCES:
+				errorMessage = QObject::tr("Cannot allocate resources.");
+				break;
+			case ERR_OPEN_FILES:
+				errorMessage = QObject::tr("Cannot read content of file '%1'.").arg(problemPath);
+				errorMessage += "\n\n";
+				errorMessage += QObject::tr("File content may be corrupted.");
+				errorMessage += "\n\n";
+				errorMessage += QObject::tr("You may try moving the affected file into a different location or try renaming it. This may solve the problem.");
+				break;
+			default:
+				break;
+			}
+			errorMessage += "\n\n";
+			errorMessage +=
+			    QObject::tr("You may try running the application with enabled logging and check the log for more detailed information.");
+			QMessageBox::critical(Q_NULLPTR,
+			    QObject::tr("Cannot Load Container Data"),
+			    errorMessage);
+			return EXIT_FAILURE;
+		}
 	}
 
 	int ret = EXIT_SUCCESS;
@@ -417,6 +522,11 @@ int main(int argc, char *argv[])
 	//logInfoNL("%s", "Enabling high DPI scaling.");
 	//QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 #endif /* >= Qt-5.6 */
+	/*
+	 * Enable icons in menus.
+	 * The default value is platform dependent and seems to be true in Qt-6.8 on macOS.
+	 */
+	QCoreApplication::setAttribute(Qt::AA_DontShowIconsInMenus, false);
 
 	if (runMode == RM_CLI) {
 		/* Parse account information. */
@@ -491,6 +601,16 @@ int main(int argc, char *argv[])
 		deallocGlobInfrastruct();
 		DlgUpdatePortable::updatePortable();
 	}
+	if (MWDbRepair::runDatabaseRepair) {
+		/* Stop everything except logging. */
+		deallocGlobContainers();
+		deallocGlobPrefs();
+		deallocGlobSettings();
+		deallocGlobInfrastruct();
+		MWDbRepair mwDbrepair;
+		mwDbrepair.show();
+		app.exec();
+	}
 
 	stop = QDateTime::currentMSecsSinceEpoch();
 	diff = stop - start;
