@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -184,6 +184,13 @@ int main(int argc, char *argv[])
 		    true);
 	}
 
+	if (!SQLiteDb::dbDriverSupport()) {
+		logError("Cannot load database driver '%s'.\n",
+		    SQLiteDb::dbDriverType.toUtf8().constData());
+		/* TODO -- throw a dialog notifying the user. */
+		return EXIT_FAILURE;
+	}
+
 	/* Initialise database-based preferences. */
 	if (Q_UNLIKELY(0 != allocGlobPrefs(*GlobInstcs::iniPrefsPtr))) {
 		return EXIT_FAILURE;
@@ -222,19 +229,12 @@ int main(int argc, char *argv[])
 	/* Start downloading the CRL files. */
 	downloadCRL();
 
-	if (!SQLiteDb::dbDriverSupport()) {
-		logError("Cannot load database driver '%s'.\n",
-		    SQLiteDb::dbDriverType.toUtf8().constData());
-		/* TODO -- throw a dialog notifying the user. */
-		return EXIT_FAILURE;
-	}
-
 	logDebugLv0NL("CLI main thread: %p.", QThread::currentThreadId());
 
 	logDebugLv0NL("App path: '%s'.",
 	    app.applicationDirPath().toUtf8().constData());
 
-	loadLocalisation(*GlobInstcs::prefsPtr);
+	loadLocalisationPrefs(*GlobInstcs::prefsPtr);
 
 	/* Ask for PIN. */
 	{
@@ -263,7 +263,7 @@ int main(int argc, char *argv[])
 	SQLiteTbls::localiseTableDescriptions();
 
 	/* Initialise database-based containers. */
-	if (Q_UNLIKELY(0 != allocGlobContainers(*GlobInstcs::prefsPtr,
+	if (Q_UNLIKELY(SUCCESS != allocGlobContainers(*GlobInstcs::prefsPtr,
 	        *GlobInstcs::iniPrefsPtr))) {
 		return EXIT_FAILURE;
 	}
