@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include <Qt> /* enum Qt::ToolButtonStyle */
 
 #include "src/common.h" /* ISDS_DOWNLOAD_TIMEOUT_MS */
+#include "src/datovka_shared/app_version_info.h"
 #include "src/datovka_shared/compat_qt/random.h"
 #include "src/datovka_shared/identifiers/account_id.h"
 #include "src/datovka_shared/json/basic.h"
@@ -180,6 +181,35 @@ int PrefsSpecific::checkNewVersionsCooldown(const Prefs &prefs)
 	return val;
 }
 
+bool PrefsSpecific::isNewVersion(Prefs &prefs)
+{
+	bool isNew = true;
+	QString storedVersion;
+
+	/*
+	 * If running app doesn't have release version then don't check.
+	 */
+	if (Q_UNLIKELY(!AppVersionInfo::isReleaseVersionString(VERSION))) {
+		return false;
+	}
+
+	prefs.strVal("application.notification_shown.last_version", storedVersion);
+
+	/*
+	 * If stored version is empty or non-release version string then behave
+	 * as having a new version.
+	 */
+	isNew = storedVersion.isEmpty()
+	    || (!AppVersionInfo::isReleaseVersionString(storedVersion))
+	    || (1 == AppVersionInfo::compareVersionStrings(VERSION, storedVersion));
+
+	if (isNew) {
+		prefs.setStrVal("application.notification_shown.last_version", VERSION);
+	}
+
+	return isNew;
+}
+
 void PrefsSpecific::setCheckNewVersionsCooldown(Prefs &prefs, int val)
 {
 	if (val < 0) {
@@ -965,3 +995,18 @@ void PrefsSpecific::setAppUiTheme(Prefs &prefs, qint64 index)
 {
 	prefs.setIntVal("application.ui.theme", index);
 }
+
+qint64 PrefsSpecific::appUiThemeFontScalePercent(const Prefs &prefs)
+{
+	qint64 val = 100;
+	if (Q_UNLIKELY(!prefs.intVal(
+		"application.ui.theme.custom.font_scale.percent", val))) {
+		return 100;
+	}
+	return val;
+}
+
+void PrefsSpecific::setAppUiThemeFontScalePercent(Prefs &prefs, qint64 percent)
+{
+	prefs.setIntVal("application.ui.theme.custom.font_scale.percent", percent);
+}
