@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2024 CZ.NIC
+ * Copyright (C) 2014-2025 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
  */
 
 #include <cinttypes>
+#include <QDateTime>
 #include <QThread>
 
 #include "src/datovka_shared/isds/error.h"
@@ -36,6 +37,7 @@
 #include "src/io/message_db_set.h"
 #include "src/isds/message_conversion.h"
 #include "src/isds/services.h"
+#include "src/isds/session.h"
 #include "src/settings/accounts.h"
 #include "src/worker/message_emitter.h"
 #include "src/worker/task_download_message.h"
@@ -43,7 +45,8 @@
 TaskDownloadMessage::TaskDownloadMessage(const AcntIdDb &acntIdDb,
     enum MessageDirection msgDirect, const MsgId &msgId, bool storeRawInDb,
     int processFlags, const QString &recMgmtHierarchyId)
-    : m_result(DM_ERR),
+    : QObject(),
+    m_result(DM_ERR),
     m_isdsError(),
     m_isdsLongError(),
     m_mId(msgId),
@@ -79,6 +82,14 @@ void TaskDownloadMessage::run(void)
 
 	/* ### Worker task begin. ### */
 
+	Isds::Session *session =
+	    GlobInstcs::isdsSessionsPtr->session(m_acntIdDb.username());
+	if (Q_NULLPTR != session) {
+		connect(session, SIGNAL(progress(qint64, qint64, qint64, qint64)),
+		    this, SLOT(watchProgress(qint64, qint64, qint64, qint64)),
+		    Qt::DirectConnection); /* Qt::DirectConnection because it must be executed immediatelly. */
+	}
+
 	const AcntId acntId(m_acntIdDb);
 
 	logDebugLv1NL("%s", "-----------------------------------------------");
@@ -102,13 +113,21 @@ void TaskDownloadMessage::run(void)
 		    GlobInstcs::acntMapPtr->acntData(acntId).accountName().toUtf8().constData());
 	}
 
-	emit GlobInstcs::msgProcEmitterPtr->downloadMessageFinished(acntId,
+	if (Q_NULLPTR != session) {
+		session->disconnect(Q_NULLPTR, this, Q_NULLPTR);
+	}
+
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->downloadProgressFinished(
+	    AcntId(m_acntIdDb.username(), m_acntIdDb.testing()), m_mId,
+	    m_result, m_isdsError + " " + m_isdsLongError);
+
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->downloadMessageFinished(acntId,
 	    m_mId.dmId(), m_mId.deliveryTime(), m_result,
 	    (!m_isdsError.isEmpty() || !m_isdsLongError.isEmpty()) ?
 	        m_isdsError + " " + m_isdsLongError : "",
 	    m_processFlags, m_recMgmtHierarchyId);
 
-	emit GlobInstcs::msgProcEmitterPtr->progressChange(PL_IDLE, 0);
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(PL_IDLE, 0);
 
 	/* ### Worker task end. ### */
 
@@ -307,7 +326,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadAndStoreSignedMess
 	logDebugLv0NL("Trying to download complete message '%" PRId64 "'",
 	    UGLY_QINT64_CAST mId.dmId());
 
-	emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 0);
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 0);
 
 	if (Q_UNLIKELY(GlobInstcs::req_halt)) {
 		return DM_ABORTED;
@@ -326,7 +345,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadAndStoreSignedMess
 	Isds::Message delInfo;
 	Isds::DmMessageAuthor dmMsgAuthor;
 
-	emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 10);
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 10);
 
 	if (Q_UNLIKELY(GlobInstcs::req_halt)) {
 		return DM_ABORTED;
@@ -338,7 +357,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadAndStoreSignedMess
 		Q_ASSERT(0);
 		logErrorNL("Cannot access database to store message '%" PRId64 "'.",
 		    UGLY_QINT64_CAST mId.dmId());
-		emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 100);
+		Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 100);
 		return DM_DB_INS_ERR;
 	}
 	bool isVodz = messageDb->isVodz(mId.dmId());
@@ -350,7 +369,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadAndStoreSignedMess
 		return msgRes;
 	}
 
-	emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 20);
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 20);
 
 	if (Q_UNLIKELY(GlobInstcs::req_halt)) {
 		return DM_ABORTED;
@@ -363,7 +382,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadAndStoreSignedMess
 		    UGLY_QINT64_CAST mId.dmId());
 	}
 
-	emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 30);
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 30);
 
 	if (Q_UNLIKELY(GlobInstcs::req_halt)) {
 		return DM_ABORTED;
@@ -376,7 +395,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadAndStoreSignedMess
 		    UGLY_QINT64_CAST mId.dmId());
 	}
 
-	emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 40);
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 40);
 
 	if (Q_UNLIKELY(GlobInstcs::req_halt)) {
 		return DM_ABORTED;
@@ -395,7 +414,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadAndStoreSignedMess
 			Q_ASSERT(0);
 			logErrorNL("Cannot access database to store message '%" PRId64 "'.",
 			    UGLY_QINT64_CAST mId.dmId());
-			emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 100);
+			Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 100);
 			return DM_DB_INS_ERR;
 		}
 
@@ -404,7 +423,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadAndStoreSignedMess
 		if (Q_UNLIKELY(!messageDb->beginTransaction())) {
 			logErrorNL("Cannot begin transaction to store message '%" PRId64 "'.",
 			    UGLY_QINT64_CAST mId.dmId());
-			emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 100);
+			Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 100);
 			messageDb->unlock();
 			return DM_DB_INS_ERR;
 		}
@@ -442,7 +461,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadAndStoreSignedMess
 
 	Q_ASSERT(message.envelope().dmId() == mId.dmId());
 
-	emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 50);
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 50);
 
 	if (Q_UNLIKELY(GlobInstcs::req_halt)) {
 		goto abort;
@@ -452,7 +471,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadAndStoreSignedMess
 	Task::storeSignedMessage(IMPLICIT_TRANSACTION, msgDirect, *dbSet,
 	    message, storeRawInDb);
 
-	emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 70);
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 70);
 
 	if (Q_UNLIKELY(GlobInstcs::req_halt)) {
 		goto abort;
@@ -473,7 +492,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadAndStoreSignedMess
 		}
 	}
 
-	emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 80);
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 80);
 
 	if (Q_UNLIKELY(GlobInstcs::req_halt)) {
 		goto abort;
@@ -492,7 +511,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadAndStoreSignedMess
 		}
 	}
 
-	emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 90);
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 90);
 
 	if (Q_UNLIKELY(GlobInstcs::req_halt)) {
 		goto abort;
@@ -517,7 +536,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadAndStoreSignedMess
 	messageDb->unlock();
 #endif /* USE_EXPLICIT_TRANSACTION */
 
-	emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 100);
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 100);
 
 	logDebugLv0NL("Done with %s().", __func__);
 
@@ -528,10 +547,21 @@ abort:
 	messageDb->rollbackTransaction();
 	messageDb->unlock();
 #endif /* USE_EXPLICIT_TRANSACTION */
-	emit GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 100);
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->progressChange(progressLabel, 100);
 	return DM_ABORTED;
 
 #undef USE_EXPLICIT_TRANSACTION
 #undef IMPLICIT_TRANSACTION
 #undef TRANSACTION_ENABLE
 }
+
+void TaskDownloadMessage::watchProgress(qint64 uploadTotal, qint64 uploadCurrent,
+    qint64 downloadTotal, qint64 downloadCurrent)
+{
+	Q_UNUSED(uploadTotal);
+	Q_UNUSED(uploadCurrent);
+
+	Q_EMIT GlobInstcs::msgProcEmitterPtr->downloadProgress(
+	    AcntId(m_acntIdDb.username(), m_acntIdDb.testing()), m_mId,
+	    downloadTotal, downloadCurrent);
+}
